CREATE OR REPLACE FUNCTION mergeOldUser(userIdToRemove integer, userIdToModify integer) RETURNS void AS $$
	update cru_changeset_comment
	set cru_user_id = $2
	where cru_user_id = $1;

	update cru_proj_allowed_reviewer as toUpdate
	set cru_user_id = $2
	where cru_user_id = $1
	and not exists(
		select 1 from cru_proj_allowed_reviewer toCheck
		where toCheck.cru_user_id = $2
		and toUpdate.cru_project_id = toCheck.cru_project_id
	);
	delete from cru_proj_allowed_reviewer
	where cru_user_id = $1;

	update cru_proj_default_reviewer as toUpdate
	set cru_user_id = $2
	where cru_user_id = $1
	and not exists(
		select 1 from cru_proj_default_reviewer toCheck
		where toCheck.cru_user_id = $2
		and toUpdate.cru_project_id = toCheck.cru_project_id
	);
	delete from cru_proj_default_reviewer
	where cru_user_id = $1;
	
	update cru_notification
	set cru_actioner = $2
	where cru_actioner = $1;
	
	update cru_review_participant as toUpdate
	set cru_user = $2
	where cru_user = $1
	and not exists(
		select 1 from cru_review_participant toCheck
		where toCheck.cru_user = $2
		and toUpdate.cru_review_id = toCheck.cru_review_id
	);
	
	delete from cru_file_read_status as fileRead
	where exists(
		select 1 from cru_review_participant partic
		where partic.cru_user = $1
		and partic.cru_participant_id = fileRead.cru_participant
	);
	
	delete from cru_review_participant
	where cru_user = $1;

	update cru_review
	set cru_creator = $2
	where cru_creator = $1;

	update cru_upload_item
	set cru_user = $2
	where cru_user = $1;

	update cru_recipient
	set cru_user = $2
	where cru_user = $1;

	update cru_project
	set cru_default_moderator = $2
	where cru_default_moderator = $1;

	update cru_comment_read_status as toUpdate
	set cru_user = $2
	where cru_user = $1
	and not exists(
		select 1 from cru_comment_read_status toCheck
		where toCheck.cru_user = $2
		and toUpdate.cru_comment = toCheck.cru_comment
	);
	delete from cru_comment_read_status
	where cru_user = $1;
	
	update cru_user_app_link as toUpdate
	set cru_user = $2
	where cru_user = $1
	and not exists(
		select 1 from cru_user_app_link toCheck
		where toCheck.cru_user = $2
		and toUpdate.cru_app_link_id = toCheck.cru_app_link_id
	);
	delete from cru_user_app_link
	where cru_user = $1;

	update cru_comment
	set cru_user_id = $2
	where cru_user_id = $1;

	update cru_state_change
	set cru_user = $2
	where cru_user = $1;
	
	update cru_logitem
	set cru_user_id = $2
	where cru_user_id = $1;
	
	update cru_logitem
	set cru_entity_id = $2
	where cru_entity_id = $1
		AND cru_action in ('REVIEW_REVIEWER_ADDED', 'REVIEW_REVIEWER_ADDED_MID_REVIEW');

	delete from cru_user_profile
	where cru_user_id = $1;
	
	delete from cru_user
	where cru_user_id = $1;
	
$$ LANGUAGE sql;


-- This select statement will remove all USER_NAMEs where there is a corresponding USER_NAME_old1 user.
-- Comment it out if you'd prefer to manually choose users.
select
	old_user.cru_user_name as oldName
,	new_user.cru_user_name as newName
,	old_user.cru_user_id as oldUserId
,	new_user.cru_user_id as newUserId
,	mergeOldUser(new_user.cru_user_id, old_user.cru_user_id)
from cru_user old_user
inner join cru_user new_user
	on new_user.cru_user_name = substring(old_user.cru_user_name from 1 for char_length(old_user.cru_user_name) - 5)
where old_user.cru_user_name like '%_old1';

-- This template will let you run the merge function on a specific pair of users.
-- Uncomment it if you'd prefer to individually choose pairs of users to revert.

--select
--	old_user.cru_user_name as oldName
--,	new_user.cru_user_name as newName
--,	old_user.cru_user_id as oldUserId
--,	new_user.cru_user_id as newUserId
--,	mergeOldUser(new_user.cru_user_id, old_user.cru_user_id)
--from cru_user old_user
--cross join cru_user new_user
--where old_user.cru_user_name = 'OLD_USER_NAME - to be modified'
--and new_user.cru_user_name = 'NEW_USER_NAME - to be removed';

